# -*- coding: utf-8 -*-

# Copyright © Spyder Project Contributors
# Licensed under the terms of the MIT License
# (see LICENSE for details)

"""Three-way merge between two strings with respect to a base one."""

# Local imports
from .merge import merge

merge

# Package version
VERSION_INFO = (0, 1, 1)
__version__ = '.'.join(map(str, VERSION_INFO))
